==> ddd-3.3.7.tar.gz: ddd-3.3.7/ddd/RefreshDI.h <==
// $Id$ -*- C++ -*-
// Refresh Disassemble Info

// Copyright (C) 1998 Technische Universitaet Braunschweig, Germany.
// Written by Andreas Zeller <zeller@gnu.org>.
// 
// This file is part of DDD.
// 
// DDD is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public
// License as published by the Free Software Foundation; either
// version 2 of the License, or (at your option) any later version.
// 
// DDD is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
// See the GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public
// License along with DDD -- see the file COPYING.
// If not, write to the Free Software Foundation, Inc.,
// 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
// 
// DDD is the data display debugger.
// For details, see the DDD World-Wide-Web page, 
// `http://www.gnu.org/software/ddd/',
// or send a mail to the DDD developers <ddd@gnu.org>.

#ifndef _DDD_RefreshDisassembleInfo_h
#define _DDD_RefreshDisassembleInfo_h

#ifdef __GNUG__
#pragma interface
#endif

#include "strclass.h"
#include "status.h"
#include <Xm/Text.h>


// This is used in SourceView.

struct RefreshDisassembleInfo {
    string pc;
    XmHighlightMode mode;
    StatusDelay delay;

private:
    // Don't use assignment or copy constructors
    RefreshDisassembleInfo(const RefreshDisassembleInfo& info)
	: pc(info.pc), mode(info.mode), delay("")
    {
	assert(0);
    }
    RefreshDisassembleInfo& operator = (const RefreshDisassembleInfo&)
    {
	assert(0); return *this;
    }

public:
    RefreshDisassembleInfo(const string& p, XmHighlightMode m,
			   const string& msg)
        : pc(p), mode(m), delay(msg)
    {}

    ~RefreshDisassembleInfo()
    {}
};

#endif // _DDD_RefreshDisassembleInfo_h
// DON'T ADD ANYTHING BEHIND THIS #endif

==> ddd-3.3.8.tar.gz: ddd-3.3.8/ddd/RefreshDI.h <==
// $Id$ -*- C++ -*-
// Refresh Disassemble Info

// Copyright (C) 1998 Technische Universitaet Braunschweig, Germany.
// Written by Andreas Zeller <zeller@gnu.org>.
// 
// This file is part of DDD.
// 
// DDD is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public
// License as published by the Free Software Foundation; either
// version 2 of the License, or (at your option) any later version.
// 
// DDD is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
// See the GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public
// License along with DDD -- see the file COPYING.
// If not, write to the Free Software Foundation, Inc.,
// 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
// 
// DDD is the data display debugger.
// For details, see the DDD World-Wide-Web page, 
// `http://www.gnu.org/software/ddd/',
// or send a mail to the DDD developers <ddd@gnu.org>.

#ifndef _DDD_RefreshDisassembleInfo_h
#define _DDD_RefreshDisassembleInfo_h

#ifdef __GNUG__
#pragma interface
#endif

#include "strclass.h"
#include "status.h"
#include <Xm/Text.h>


// This is used in SourceView.

struct RefreshDisassembleInfo {
    string pc;
    XmHighlightMode mode;
    StatusDelay delay;

private:
    // Don't use assignment or copy constructors
    RefreshDisassembleInfo(const RefreshDisassembleInfo&);
    RefreshDisassembleInfo& operator = (const RefreshDisassembleInfo&);

public:
    RefreshDisassembleInfo(const string& p, XmHighlightMode m,
			   const string& msg)
        : pc(p), mode(m), delay(msg)
    {}

    ~RefreshDisassembleInfo()
    {}
};

#endif // _DDD_RefreshDisassembleInfo_h
// DON'T ADD ANYTHING BEHIND THIS #endif
